--
-- Create new mailsql database
--
CREATE DATABASE IF NOT EXISTS mailsql;

--
-- Create new user that will be used to access database
-- You should change password 'secret' to something more secure
-- If you are using MySQL running on some different machine
-- than replace 'localhost' with appropriate domain name or '%'
--
GRANT SELECT,INSERT,UPDATE,DELETE,CREATE,DROP
  ON mailsql.* TO 'mailsql'@'localhost'
  IDENTIFIED BY 'secret';

--
-- Apply new (user) privileges (do I need this?)
--
FLUSH PRIVILEGES;

--
-- Create mailsql databases
--
USE mailsql;

CREATE TABLE IF NOT EXISTS `mail` (
  `host`        VARCHAR(40)  NOT NULL,
  `queue_id`    VARBINARY(15) NOT NULL,
  `order`       UNSIGNED INT NOT NULL auto_increment,
  `time_iso`    timestamp    NOT NULL,
  `client_name` VARCHAR(40)  DEFAULT '',
  `client_ip`   VARCHAR(40)  DEFAULT '',
  `parent_id`   VARBINARY(15) DEFAULT '',
--  `msg_id`      VARCHAR(50)  DEFAULT '',
  `helo`        VARCHAR(50)  DEFAULT '',
--  `sender`      VARCHAR(100) DEFAULT '',
  `proto`       VARCHAR(12)  DEFAULT '',
--  `size`        INT UNSIGNED DEFAULT 0,
--  `nrcpt`       SMALLINT UNSIGNED DEFAULT 0,
  `pid`         INT          DEFAULT 0,
  `tls`         BOOLEAN DEFAULT FALSE,
  PRIMARY KEY (`queue_id`, `host`),
  INDEX (`client_ip`),
--  INDEX (`sender`),
--  INDEX (`msg_id`),
) ENGINE=InnoDB DEFAULT CHARSET=latin1 MAX_ROWS=1000000000;

CREATE TABLE IF NOT EXISTS `msgid` (
  `host`        VARCHAR(40)  NOT NULL,
  `queue_id`    VARBINARY(15) NOT NULL,
  `msg_id`      VARCHAR(50)  DEFAULT '',
  FOREIGN KEY (`queue_id`, `host`)     REFERENCES `mail`(`queue_id`, `host`) ON DELETE CASCADE,
  INDEX (`msg_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 MAX_ROWS=1000000000;

CREATE TABLE IF NOT EXISTS `sender` (
  `host`        VARCHAR(40)  NOT NULL,
  `queue_id`    VARBINARY(15) NOT NULL,
  `sender`      VARCHAR(100) DEFAULT '',
  `size`        INT UNSIGNED DEFAULT 0,
  `nrcpt`       SMALLINT UNSIGNED DEFAULT 0,
  FOREIGN KEY (`queue_id`, `host`)     REFERENCES `mail`(`queue_id`, `host`) ON DELETE CASCADE,
  INDEX (`sender`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 MAX_ROWS=1000000000;

CREATE TABLE IF NOT EXISTS `recip` (
  `host`        VARCHAR(40)  NOT NULL,
  `queue_id`    VARBINARY(15) NOT NULL,
  `time_iso`    timestamp    NOT NULL,
  `recip`       VARCHAR(100) NOT NULL,
  `recip_orig`  VARCHAR(100) DEFAULT '',
  `relay`       VARCHAR(100) DEFAULT '',
  `code`        SMALLINT UNSIGNED DEFAULT 0,
  `status`      VARCHAR(20) DEFAULT '',
  `info`        VARCHAR(255) DEFAULT '',
  FOREIGN KEY (`queue_id`, `host`)     REFERENCES `mail`(`queue_id`, `host`) ON DELETE CASCADE,
  INDEX (`recip`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 MAX_ROWS=1000000000;

CREATE TABLE IF NOT EXISTS `amavis` (
  `host`        VARCHAR(40)  NOT NULL,
  `queue_id`    VARBINARY(15) NOT NULL,
  `parent_id`   VARBINARY(15) DEFAULT '',
  `amavis_id`   VARBINARY(16) NOT NULL,
--  `msg_id`      VARCHAR(50)  DEFAULT '',
  `hits`        FLOAT        DEFAULT NULL,
  `size`        INT          DEFAULT NULL,
  `time`        INT          DEFAULT NULL,
  `pid`         INT          DEFAULT 0,
  FOREIGN KEY (`queue_id`, `host`)     REFERENCES `%s`(`queue_id`, `host`) ON DELETE CASCADE,
  INDEX (`amavis_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 MAX_ROWS=1000000000;
